summaryrefslogtreecommitdiffstats
path: root/kdat/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/main.cpp')
-rw-r--r--kdat/main.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/main.cpp b/kdat/main.cpp
index 34704da..7a70f8d 100644
--- a/kdat/main.cpp
+++ b/kdat/main.cpp
@@ -72,9 +72,9 @@ int main( int argc, char** argv )
#endif /* DEBUG */
/* 2002-01-28 LEW */
- KCmdLineArgs::init( argc, argv, &aboutData );
+ TDECmdLineArgs::init( argc, argv, &aboutData );
aboutData.addAuthor( "Lawrence Widman", 0, "kdat@cardiothink.com");
// KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
KApplication app;
app.setMainWidget( KDatMainWindow::getInstance() );
@@ -72,9 +72,9 @@ int main( int argc, char** argv )
aboutData.addAuthor( "Lawrence Widman", 0, "kdat@cardiothink.com");
-// KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+// TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
KApplication app;
app.setMainWidget( KDatMainWindow::getInstance() );